@@ -36,6 +36,9 @@ class COINNReducer:
                                        chunksize=self.cache['reduction_chunk_size']))
 
         avg_grads = list(self.pool.starmap(_mean, list(zip(*grads)), chunksize=self.cache['reduction_chunk_size']))
+        avg_grads = [
+            arr.astype(f"float{self.cache.setdefault('precision_bits', _conf.grad_precision_bit)}") for arr in avg_grads
+        ]
         _tu.save_arrays(
             self.state['transferDirectory'] + _os.sep + out['avg_grads_file'],
             _np.array(avg_grads, dtype=object)
